@@ -1,7 +1,7 @@
 from .abstractLogMessages import *
 from .abstractAccountKeysManager import *
 from .abstractInstructionManager import *
-from mabstract_apis import get_response,requests
+from abstract_apis import get_response,requests
 class TransactionProcessor:
     def __init__(self, txnData=None,signature=None,instruction_mgr = None,account_mgr=None,log_mgr=None,**kwargs):
         txnData = txnData or self.make_txn_request(signature,**kwargs)
